==> sfa-rpc-0.0.11-sources.jar: com/biz/sfa/vo/req/DistributionPositionVo.java <==
package com.biz.sfa.vo.req;

import java.io.Serializable;

/**
 * @author zhangqiang:
 * @version 创建时间：2017年6月27日 下午2:52:47 分配岗位
 */
public class DistributionPositionVo implements Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = 5683417894052967442L;

	// 被分配岗位编码
	private String distributionPosCode;

	// 被分配岗位下人员姓名
	private String distributionFullName;

	// 分配时间
	private Long createDate;

	// 执行分配岗位编码
	private String createPostionCode;
	
	// 执行分配岗位下人员
	private String createUser;

	// 人员对应经销商编码
	private String franchiserCode;

	// 人员对应经销商名称
	private String franchiserName;

	public String getDistributionPosCode() {
		return distributionPosCode;
	}

	public void setDistributionPosCode(String distributionPosCode) {
		this.distributionPosCode = distributionPosCode;
	}

	public String getDistributionFullName() {
		return distributionFullName;
	}

	public void setDistributionFullName(String distributionFullName) {
		this.distributionFullName = distributionFullName;
	}

	public Long getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Long createDate) {
		this.createDate = createDate;
	}

	public String getCreatePostionCode() {
		return createPostionCode;
	}

	public void setCreatePostionCode(String createPostionCode) {
		this.createPostionCode = createPostionCode;
	}

	public String getFranchiserCode() {
		return franchiserCode;
	}

	public void setFranchiserCode(String franchiserCode) {
		this.franchiserCode = franchiserCode;
	}

	public String getFranchiserName() {
		return franchiserName;
	}

	public void setFranchiserName(String franchiserName) {
		this.franchiserName = franchiserName;
	}

	public String getCreateUser() {
		return createUser;
	}

	public void setCreateUser(String createUser) {
		this.createUser = createUser;
	}

}

==> sfa-rpc-0.0.60-sources.jar: com/biz/sfa/vo/req/DistributionPositionVo.java <==
package com.biz.sfa.vo.req;

import java.io.Serializable;

/**
 * @author zhangqiang:
 * @version 创建时间：2017年6月27日 下午2:52:47 分配岗位
 */
public class DistributionPositionVo implements Serializable {
	/**
	 * 
	 */
	private static final long serialVersionUID = 5683417894052967442L;

	// 被分配岗位编码
	private String distributionPosCode;
	// 被分配岗位名称
	private String distributionPosName;

	// 被分配岗位下人员姓名
	private String distributionFullName;

	// 分配时间
	private Long createDate;

	// 执行分配岗位编码
	private String createPostionCode;
	
	// 执行分配岗位下人员
	private String createUser;

	// 人员对应经销商编码
	private String franchiserCode;

	// 人员对应经销商名称
	private String franchiserName;

	public String getDistributionPosCode() {
		return distributionPosCode;
	}

	public void setDistributionPosCode(String distributionPosCode) {
		this.distributionPosCode = distributionPosCode;
	}

	public String getDistributionFullName() {
		return distributionFullName;
	}

	public void setDistributionFullName(String distributionFullName) {
		this.distributionFullName = distributionFullName;
	}

	public Long getCreateDate() {
		return createDate;
	}

	public void setCreateDate(Long createDate) {
		this.createDate = createDate;
	}

	public String getCreatePostionCode() {
		return createPostionCode;
	}

	public void setCreatePostionCode(String createPostionCode) {
		this.createPostionCode = createPostionCode;
	}

	public String getFranchiserCode() {
		return franchiserCode;
	}

	public void setFranchiserCode(String franchiserCode) {
		this.franchiserCode = franchiserCode;
	}

	public String getFranchiserName() {
		return franchiserName;
	}

	public void setFranchiserName(String franchiserName) {
		this.franchiserName = franchiserName;
	}

	public String getCreateUser() {
		return createUser;
	}

	public void setCreateUser(String createUser) {
		this.createUser = createUser;
	}

	public String getDistributionPosName() {
		return distributionPosName;
	}

	public void setDistributionPosName(String distributionPosName) {
		this.distributionPosName = distributionPosName;
	}

}
